==> sourcehutx-0.0.2.tar.gz: sourcehutx-0.0.2/noxfile.py <==
# Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT

from __future__ import annotations

import os
from glob import iglob
from pathlib import Path
from shutil import copy2
from typing import cast

import nox

IN_CI = "JOB_ID" in os.environ or "CI" in os.environ
ALLOW_EDITABLE = os.environ.get("ALLOW_EDITABLE", str(not IN_CI)).lower() in (
    "1",
    "true",
)

PROJECT = "sourcehut"
SPECFILE = "python-sourcehutx.spec"
LINT_SESSIONS = ("formatters", "codeqa", "typing")
LINT_FILES = (f"src/{PROJECT}", "tests/", "noxfile.py")
RELEASERR = "releaserr[all] @ git+https://git.sr.ht/~gotmax23/releaserr"
# RELEASERR = "-e../releaserr[all]"

nox.options.sessions = (*LINT_SESSIONS, "test", "test_pydanticv1")


# Helpers


def install(session: nox.Session, *args, editable=False, **kwargs):
    if editable and ALLOW_EDITABLE:
        args = ("-e", *args)
    session.install(*args, **kwargs)


def git(session: nox.Session, *args, **kwargs):
    return session.run("git", *args, **kwargs, external=True)


# General


@nox.session(python=["3.8", "3.9", "3.10", "3.11", "3.12"], tags=["test"])
def test(session: nox.Session):
    install(
        session,
        ".[test]",
        # httpx: use surrogateescape to allow for binary data
        # https://github.com/kevin1024/vcrpy/pull/760
        "git+https://github.com/gotmax23/vcrpy.git@binary_httpx",
        editable=True,
    )

    args = list(session.posargs)
    tmp = Path(session.create_tmp())
    env: dict[str, str] = {}

    if any(i.startswith("--cov") for i in session.posargs):
        install(session, "coverage[toml]", "pytest-cov")
        env |= {"COVERAGE_FILE": str(tmp / ".coverage")}
    has_deprecation_warning = session.run(
        "python",
        "-c",
        "import pydantic; print(hasattr(pydantic, 'PydanticDeprecatedSince20'))",
        silent=True,
    )
    if cast(str, has_deprecation_warning).strip() == "True":
        args.extend(("-W", "ignore::pydantic.PydanticDeprecatedSince20"))
    session.run("pytest", *args, env=env)


@nox.session(tags=["test"])
def test_pydanticv1(session: nox.Session):
    session.install("pydantic ~= 1.0")
    test(session)


@nox.session
def coverage(session: nox.Session):
    install(session, "coverage[toml]")
    session.run("coverage", "combine", "--keep", *iglob(".nox/test*/tmp/.coverage"))
    session.run("coverage", "html")
    session.run("coverage", "report", "--fail-under=94")


@nox.session()
def covtest(session: nox.Session):
    posargs = (*session.posargs, "--cov=sourcehut")
    test_sessions = (f"test-{v}" for v in test.python)  # type: ignore[attr-defined]
    for target in (*test_sessions, "test_pydanticv1", "coverage"):
        session.notify(target, posargs)


@nox.session(venv_backend="none")
def lint(session: nox.Session):
    """
    Run formatters, codeqa, and typing sessions
    """
    for notify in LINT_SESSIONS:
        session.notify(notify)


@nox.session
def codeqa(session: nox.Session):
    install(session, ".[codeqa]")
    session.run("ruff", *session.posargs, *LINT_FILES)
    session.run("reuse", "lint")


@nox.session
def formatters(session: nox.Session):
    install(session, ".[formatters]")
    posargs = session.posargs
    if IN_CI:
        posargs.append("--check")
    session.run("black", *posargs, *LINT_FILES)
    session.run("isort", *posargs, *LINT_FILES)


@nox.session
def typing(session: nox.Session):
    install(session, ".[typing]", editable=True)
    session.run("mypy", *LINT_FILES)


@nox.session
def bump(session: nox.Session):
    version = session.posargs[0]

    install(session, RELEASERR, "fclogr")

    session.run("releaserr", "check-tag", version)
    session.run("releaserr", "ensure-clean")
    session.run("releaserr", "set-version", "-s", "file", version)

    install(session, ".")

    # Bump specfile
    # fmt: off
    session.run(
        "fclogr", "bump",
        "--new", version,
        "--comment", f"Release {version}.",
        SPECFILE,
    )
    # fmt: on

    # Bump changelog, commit, and tag
    git(session, "add", SPECFILE, f"src/{PROJECT}/__init__.py")
    session.run("releaserr", "clog", version, "--tag")
    session.run("releaserr", "build", "--sign", "--isolated")


@nox.session
def publish(session: nox.Session):
    # Setup
    install(session, RELEASERR)
    session.run("releaserr", "ensure-clean")

    # Upload to PyPI
    session.run("releaserr", "upload")

    # Push to git, publish artifacts to sourcehut, and release to copr
    if not session.interactive or input(
        "Push to Sourcehut and copr build (Y/n)"
    ).lower() in ("", "y"):
        git(session, "push", "--follow-tags")
        session.run("hut", "git", "artifact", "upload", *iglob("dist/*"), external=True)
        copr_release(session)

    # Post-release bump
    session.run("releaserr", "post-version", "-s", "file")
    git(session, "add", "src/{PROJECT}/__init__.py")
    git(session, "commit", "-S", "-m", "Post release version bump")


@nox.session
def copr_release(session: nox.Session):
    install(session, "copr-cli", "requests-gssapi", "specfile")
    tmp = Path(session.create_tmp())
    dest = tmp / SPECFILE
    copy2(SPECFILE, dest)
    session.run("python", "contrib/fedoraify.py", str(dest))
    session.run("copr-cli", "build", "--nowait", f"gotmax23/{PROJECT}", str(dest))


@nox.session
def srpm(session: nox.Session, posargs=None):
    install(session, "fclogr")
    posargs = posargs or session.posargs
    session.run("fclogr", "--debug", "dev-srpm", *posargs, SPECFILE)


@nox.session
def mockbuild(session: nox.Session):
    tmp = Path(session.create_tmp())
    srpm(session, ("-o", tmp, "--keep"))
    margs = [
        "mock",
        "--spec",
        str(Path(tmp, SPECFILE)),
        "--source",
        str(tmp),
        *session.posargs,
    ]
    if not session.interactive:
        margs.append("--verbose")
    session.run(*margs, external=True)

==> sourcehutx-0.2.0.tar.gz: sourcehutx-0.2.0/noxfile.py <==
# Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT

from __future__ import annotations

import os
from glob import iglob
from pathlib import Path
from shutil import copy2
from typing import cast

import nox

IN_CI = "JOB_ID" in os.environ or "CI" in os.environ
ALLOW_EDITABLE = os.environ.get("ALLOW_EDITABLE", str(not IN_CI)).lower() in (
    "1",
    "true",
)

PROJECT = "sourcehut"
SPECFILE = "python-sourcehutx.spec"
LINT_SESSIONS = ("formatters", "codeqa", "typing")
LINT_FILES = (f"src/{PROJECT}", "tests/", "noxfile.py")
RELEASERR = "releaserr[all] @ git+https://git.sr.ht/~gotmax23/releaserr"
# RELEASERR = "-e../releaserr[all]"

nox.options.sessions = (*LINT_SESSIONS, "test", "test_pydanticv1")


# Helpers


def install(session: nox.Session, *args, editable=False, **kwargs):
    if editable and ALLOW_EDITABLE:
        args = ("-e", *args)
    session.install(*args, **kwargs)


def git(session: nox.Session, *args, **kwargs):
    return session.run("git", *args, **kwargs, external=True)


# General


@nox.session(python=["3.8", "3.9", "3.10", "3.11", "3.12"], tags=["test"])
def test(session: nox.Session):
    install(
        session,
        ".[test]",
        # httpx: use surrogateescape to allow for binary data
        # https://github.com/kevin1024/vcrpy/pull/760
        "git+https://github.com/gotmax23/vcrpy.git@binary_httpx",
        editable=True,
    )

    args = list(session.posargs)
    tmp = Path(session.create_tmp())
    env: dict[str, str] = {}

    if any(i.startswith("--cov") for i in session.posargs):
        install(session, "coverage[toml]", "pytest-cov")
        env |= {"COVERAGE_FILE": str(tmp / ".coverage")}
    has_deprecation_warning = session.run(
        "python",
        "-c",
        "import pydantic; print(hasattr(pydantic, 'PydanticDeprecatedSince20'))",
        silent=True,
    )
    if cast(str, has_deprecation_warning).strip() == "True":
        args.extend(("-W", "ignore::pydantic.PydanticDeprecatedSince20"))
    session.run("pytest", *args, env=env)


@nox.session(tags=["test"])
def test_pydanticv1(session: nox.Session):
    session.install("pydantic ~= 1.0")
    test(session)


@nox.session
def coverage(session: nox.Session):
    install(session, "coverage[toml]")
    session.run("coverage", "combine", "--keep", *iglob(".nox/test*/tmp/.coverage"))
    session.run("coverage", "html")
    session.run("coverage", "report", "--fail-under=94")


@nox.session()
def covtest(session: nox.Session):
    posargs = (*session.posargs, "--cov=sourcehut")
    test_sessions = (f"test-{v}" for v in test.python)  # type: ignore[attr-defined]
    for target in (*test_sessions, "test_pydanticv1", "coverage"):
        session.notify(target, posargs)


@nox.session(venv_backend="none")
def lint(session: nox.Session):
    """
    Run formatters, codeqa, and typing sessions
    """
    for notify in LINT_SESSIONS:
        session.notify(notify)


@nox.session
def codeqa(session: nox.Session):
    install(session, ".[codeqa]")
    session.run("ruff", *session.posargs, *LINT_FILES)
    session.run("reuse", "lint")


@nox.session
def formatters(session: nox.Session):
    install(session, ".[formatters]")
    posargs = session.posargs
    if IN_CI:
        posargs.append("--check")
    session.run("black", *posargs, *LINT_FILES)
    session.run("isort", *posargs, *LINT_FILES)


@nox.session
def typing(session: nox.Session):
    install(session, ".[typing]", editable=True)
    session.run("mypy", *LINT_FILES)


@nox.session
def bump(session: nox.Session):
    version = session.posargs[0]

    install(session, RELEASERR, "fclogr")

    session.run("releaserr", "check-tag", version)
    session.run("releaserr", "ensure-clean")
    session.run("releaserr", "set-version", "-s", "file", version)

    install(session, ".")

    # Bump specfile
    # fmt: off
    session.run(
        "fclogr", "bump",
        "--new", version,
        "--comment", f"Release {version}.",
        SPECFILE,
    )
    # fmt: on

    # Bump changelog, commit, and tag
    git(session, "add", SPECFILE, f"src/{PROJECT}/__init__.py")
    session.run("releaserr", "clog", version, "--tag")
    session.run("releaserr", "build", "--sign", "--isolated")


@nox.session
def publish(session: nox.Session):
    # Setup
    install(session, RELEASERR)
    session.run("releaserr", "ensure-clean")

    # Upload to PyPI
    session.run("releaserr", "upload")

    # Push to git, publish artifacts to sourcehut, and release to copr
    if not session.interactive or input(
        "Push to Sourcehut and copr build (Y/n)"
    ).lower() in ("", "y"):
        git(session, "push", "--follow-tags")
        session.run("hut", "git", "artifact", "upload", *iglob("dist/*"), external=True)
        copr_release(session)

    # Post-release bump
    session.run("releaserr", "post-version", "-s", "file")
    git(session, "add", f"src/{PROJECT}/__init__.py")
    git(session, "commit", "-S", "-m", "Post release version bump")


@nox.session
def copr_release(session: nox.Session):
    install(session, "copr-cli", "requests-gssapi", "specfile")
    tmp = Path(session.create_tmp())
    dest = tmp / SPECFILE
    copy2(SPECFILE, dest)
    session.run("python", "contrib/fedoraify.py", str(dest))
    session.run("copr-cli", "build", "--nowait", f"gotmax23/{PROJECT}", str(dest))


@nox.session
def srpm(session: nox.Session, posargs=None):
    install(session, "fclogr")
    posargs = posargs or session.posargs
    session.run("fclogr", "--debug", "dev-srpm", *posargs, SPECFILE)


@nox.session
def mockbuild(session: nox.Session):
    tmp = Path(session.create_tmp())
    srpm(session, ("-o", tmp, "--keep"))
    margs = [
        "mock",
        "--spec",
        str(Path(tmp, SPECFILE)),
        "--source",
        str(tmp),
        *session.posargs,
    ]
    if not session.interactive:
        margs.append("--verbose")
    session.run(*margs, external=True)
